#! /usr/local/bin/node

const URL = process.argv[2]

const ethers = require("ethers")

provider = new ethers.providers.JsonRpcProvider(URL)



// Are we OK on memory? Die gracefully if not
const memOK = () => {
    const mem = process.memoryUsage()
    const heap = mem.heapTotal - mem.heapUsed
    return heap > 50    // 50 MB
}  // memOK


const main = async () => {
    let snarfResult = {
        blocks: [],
        transactions: {},
    }
    snarfResult.blockNumber = await provider.getBlockNumber()

    for(var i=0; i<snarfResult.blockNumber; i++) {
        console.log(`Snarfing block #: ${i}`)
        const block = await provider.getBlock(i)
        snarfResult.blocks.push(block)
        for(var j=0; j<block.transactions.length; j++) {
            console.log(`  TX #: ${j}`)
            const tx = await provider.getTransaction(block.transactions[j])
            snarfResult.transactions[block.transactions[j]] = tx
        }
    }

    console.log(JSON.stringify(snarfResult, null, 2))
}   // main


main().then(() => process.exit(0))
  .catch((error) => {
    console.error(error)
    process.exit(1)
  })

